Stan Math Library: stan/math/prim/scal/fun/grad_reg_inc_beta.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
grad_reg_inc_beta.hpp File Reference
`#include <stan/math/prim/scal/fun/grad_inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/inc_beta.hpp>`
`#include <stan/math/prim/scal/fun/lbeta.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
void | stan::math::grad_reg_inc_beta (T &g1, T &g2, T a, T b, T z, T digammaA, T digammaB, T digammaSum, T betaAB)

[ Stan Home Page ] © 2011–2016, Stan Development Team.